:mod:`easymode.i18n`
====================

.. automodule:: easymode.i18n
    :members:

:mod:`easymode.i18n.decorators`
===============================

.. automodule:: easymode.i18n.decorators
    :members:

:mod:`easymode.i18n.admin.decorators`
=====================================

.. automodule:: easymode.i18n.admin.decorators
    :members: